py4j.reflection (py4j-java 0.10.0 API)
Date: 2016-04-18

# Package py4j.reflection

- Interface Summary
  Interface | Description
  --- | ---
  ClassLoadingStrategy | Strategy interface to load a class from a fully qualified name.

- Class Summary
  Class | Description
  --- | ---
  CurrentThreadClassLoadingStrategy | This class loading strategy uses the current thread's ClassLoader to load a class from a fully qualified name.
  LRUCache<K,V> | Implementation of a Least Recently Used cache.
  MethodDescriptor | A MethodDescriptor wraps the signature of a method (name, container, parameters).
  MethodInvoker | A MethodInvoker translates a call made in a Python Program into a call to a Java method.
  PythonProxyHandler | A PythonProxyHandler is used in place of a Python object.
  ReflectionEngine | The reflection engine is responsible for accessing the classes, the instances and members in a JVM.
  ReflectionUtil | Global utility to load classes and perform general reflection operations that can be customized by Strategy classes.
  RootClassLoadingStrategy | This class loading strategy just uses the root ClassLoader to load a class from a fully qualified name.
  TypeConverter | A TypeConverter converts a Python type into a Java Type.
  TypeUtil | This class is responsible for the type conversion between Python types and Java types.